
#line 104 "gaa.skel"
/* GAA HEADER */
#ifndef GAA_HEADER_POKY
#define GAA_HEADER_POKY

typedef struct _gaainfo gaainfo;

struct _gaainfo
{
#line 52 "shash.gaa"
	char **input;
#line 51 "shash.gaa"
	int size;
#line 42 "shash.gaa"
	char *keys;
#line 36 "shash.gaa"
	char *algorithm;
#line 33 "shash.gaa"
	char *config_file;
#line 32 "shash.gaa"
	int config;
#line 28 "shash.gaa"
	char *kmode;
#line 25 "shash.gaa"
	int text;
#line 22 "shash.gaa"
	int binary;
#line 19 "shash.gaa"
	int check;
#line 16 "shash.gaa"
	int double_check;
#line 13 "shash.gaa"
	int hmac;
#line 10 "shash.gaa"
	int show_time;
#line 7 "shash.gaa"
	int nosalt;
#line 3 "shash.gaa"
	int quiet;

#line 114 "gaa.skel"
};

#ifdef __cplusplus
extern "C"
{
#endif

    int gaa(int argc, char *argv[], gaainfo *gaaval);

    void gaa_help(void);
    
    int gaa_file(char *name, gaainfo *gaaval);
    
#ifdef __cplusplus
}
#endif


#endif
